import {
  IonModal,
  IonToolbar,
  IonTitle,
  IonButtons,
  IonButton,
  IonContent,
  IonLabel,
  IonList,
  IonListHeader,
  IonItem,
  IonSpinner,
} from '@ionic/react';
import React, { useRef, useState } from 'react';
import { useSelector } from 'react-redux';
import i18n from '../../i18n';
import { MapState } from '../../store/map';

const LocationInfo: React.FC<{}> = () => {
  const scope = useSelector((state: { map: MapState }) => state.map.scope);

  const modal = useRef<HTMLIonModalElement>(null);

  const dismiss = () => {
    modal.current?.dismiss();
  };

  const [elevation, setElevation] = useState(undefined);
  const [address, setAddress] = useState<{ display_name: any } | undefined>(
    undefined
  );

  const findElevation = async () => {
    setElevation(undefined);
    const response = await fetch(
      //     `https://api.opentopodata.org/v1/mapzen?locations=${scope.center.lat},${scope.center.lon}`,
      `https://api.open-meteo.com/v1/elevation?latitude=${scope.center.lat}&longitude=${scope.center.lon}`,
      {}
    );
    const data = await response.json();
    setElevation(data.elevation[0]);
  };

  const findAddress = async () => {
    setAddress(undefined);
    const response = await fetch(
      `https://nominatim.openstreetmap.org/reverse?lat=${
        scope.center.lat
      }&lon=${
        scope.center.lon
      }&format=jsonv2&addressdetails=1&extratags=1&namedetails=1&accept-language=${i18n.getLanguage()}`,
      {}
    );
    const data = await response.json();
    console.log(JSON.stringify(data));
    setAddress(data);
  };

  const ionModalWillPresentHandler = async () => {
    findElevation();
    findAddress();
  };

  return (
    <IonModal
      trigger='information-request'
      ref={modal}
      onIonModalWillPresent={ionModalWillPresentHandler}
    >
      <IonToolbar>
        <IonTitle>{i18n.locationInfo!.title}</IonTitle>
        <IonButtons slot='end'>
          <IonButton onClick={() => dismiss()}>{i18n.close}</IonButton>
        </IonButtons>
      </IonToolbar>
      <IonContent>
        <IonList lines='full' class='ion-no-margin'>
          <IonListHeader lines='full'>
            <IonLabel>{i18n.locationInfo!.location}</IonLabel>
          </IonListHeader>
          <IonItem>
            <IonLabel>{i18n.locationInfo!.lat}</IonLabel>
            {scope.center.lat} N
          </IonItem>
          <IonItem>
            <IonLabel>{i18n.locationInfo!.lon}</IonLabel>
            {scope.center.lon} E
          </IonItem>
          <IonItem>
            <IonLabel>{i18n.locationInfo!.elevation}</IonLabel>
            {elevation === undefined && <IonSpinner name='lines' />}
            {elevation !== undefined && <>{elevation} m</>}
          </IonItem>
        </IonList>
        <IonList lines='full' class='ion-no-margin'>
          <IonListHeader lines='full'>
            <IonLabel>{i18n.locationInfo!.address}</IonLabel>
          </IonListHeader>
          <IonItem>
            <IonLabel>{i18n.locationInfo!.display_name}</IonLabel>
            {address === undefined && <IonSpinner name='lines' />}
            {address !== undefined &&
              address.display_name.split(',').map((value: string) => (
                <>
                  {value}
                  <br />
                </>
              ))}
          </IonItem>
        </IonList>
      </IonContent>
    </IonModal>
  );
};

export default LocationInfo;
